@@ -1,6 +1,6 @@
 package Code::TidyAll::Git::Precommit;
 BEGIN {
-  $Code::TidyAll::Git::Precommit::VERSION = '0.11';
+  $Code::TidyAll::Git::Precommit::VERSION = '0.12';
 }
 use Capture::Tiny qw(capture_stdout capture_stderr);
 use Code::TidyAll;
@@ -13,7 +13,7 @@ use Moo;
 use Try::Tiny;
 
 # Public
-has 'conf_file'       => ( is => 'ro', default => sub { "tidyall.ini" } );
+has 'conf_name'       => ( is => 'ro' );
 has 'git_path'        => ( is => 'ro', default => sub { 'git' } );
 has 'no_stash'        => ( is => 'ro' );
 has 'reject_on_error' => ( is => 'ro' );
@@ -32,8 +32,10 @@ sub check {
         # Find conf file at git root
         my $root_dir = capturex( $self->git_path, "rev-parse", "--show-toplevel" );
         chomp($root_dir);
-        my $conf_file = join( "/", $root_dir, $self->conf_file );
-        die "could not find conf file '$conf_file'" unless -f $conf_file;
+        my @conf_names =
+          $self->conf_name ? ( $self->conf_name ) : Code::TidyAll->default_conf_names;
+        my ($conf_file) = grep { -f } map { join( "/", $root_dir, $_ ) } @conf_names
+          or die sprintf( "could not find conf file %s", join( " or ", @conf_names ) );
 
         # Store the stash, and restore it upon exiting this scope
         unless ( $self->no_stash ) {
@@ -80,7 +82,7 @@ tidyall'd
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -126,8 +128,8 @@ In an emergency the hook can be bypassed by passing --no-verify to commit:
 
 or you can just move C<.git/hooks/pre-commit> out of the way temporarily.
 
-The configuration file C<tidyall.ini> must be checked into git in the repo root
-directory i.e. next to the .git directory.
+The configuration file (C<tidyall.ini> or C<.tidyallrc>) must be checked into
+git in the repo root directory i.e. next to the .git directory.
 
 The hook will stash any changes not in the index beforehand, and restore them
 afterwards, via
@@ -136,8 +138,8 @@ afterwards, via
     ....
     git stash pop -q
 
-This means that if C<tidyall.ini> has uncommitted changes that are not in the
-index, they will not affect the tidyall run.
+This means that if the configuration file has uncommitted changes that are not
+in the index, they will not affect the tidyall run.
 
 Passes mode = "commit" by default; see L<modes|tidyall/MODES>.
 
@@ -145,6 +147,10 @@ Key/value parameters:
 
 =over
 
+=item conf_name
+
+Conf file name to search for instead of the defaults.
+
 =item git_path
 
 Path to git to use in commands, e.g. '/usr/bin/git' or '/usr/local/bin/git'. By
