@@ -1,20 +1,23 @@
 package Code::TidyAll::Git::Prereceive;
 BEGIN {
-  $Code::TidyAll::Git::Prereceive::VERSION = '0.11';
+  $Code::TidyAll::Git::Prereceive::VERSION = '0.12';
 }
 use Code::TidyAll;
-use Code::TidyAll::Util qw(realpath tempdir_simple write_file);
+use Code::TidyAll::Util qw(dirname realpath tempdir_simple read_file write_file);
+use Capture::Tiny qw(capture);
+use Digest::SHA1 qw(sha1_hex);
 use IPC::System::Simple qw(capturex run);
 use Moo;
 use Try::Tiny;
 
 # Public
-has 'conf_file'        => ( is => 'ro', default => sub { "tidyall.ini" } );
-has 'extra_conf_files' => ( is => 'ro', default => sub { [] } );
-has 'git_path'         => ( is => 'ro', default => sub { 'git' } );
-has 'reject_on_error'  => ( is => 'ro' );
-has 'tidyall_class'    => ( is => 'ro', default => sub { "Code::TidyAll" } );
-has 'tidyall_options'  => ( is => 'ro', default => sub { {} } );
+has 'allow_repeated_push' => ( is => 'ro', default => sub { 3 } );
+has 'conf_name'           => ( is => 'ro' );
+has 'extra_conf_files'    => ( is => 'ro', default => sub { [] } );
+has 'git_path'            => ( is => 'ro', default => sub { 'git' } );
+has 'reject_on_error'     => ( is => 'ro' );
+has 'tidyall_class'       => ( is => 'ro', default => sub { "Code::TidyAll" } );
+has 'tidyall_options'     => ( is => 'ro', default => sub { {} } );
 
 sub check {
     my ( $class, %params ) = @_;
@@ -27,8 +30,10 @@ sub check {
         my $root_dir = realpath();
         local $ENV{GIT_DIR} = $root_dir;
 
-        my ( @results, $conf_file, $tidyall );
-        while ( my $line = <> ) {
+        my ( @results, $tidyall );
+        my $input = do { local $/; <STDIN> };
+        my @lines = split( "\n", $input );
+        foreach my $line (@lines) {
             chomp($line);
             my ( $base, $commit, $ref ) = split( /\s+/, $line );
             next unless $ref eq 'refs/heads/master';
@@ -45,9 +50,11 @@ sub check {
         }
 
         if ( my @error_results = grep { $_->error } @results ) {
-            my $error_count = scalar(@error_results);
-            $fail_msg = sprintf( "%d file%s did not pass tidyall check",
-                $error_count, $error_count > 1 ? "s" : "" );
+            unless ( $self->check_repeated_push($input) ) {
+                my $error_count = scalar(@error_results);
+                $fail_msg = sprintf( "%d file%s did not pass tidyall check",
+                    $error_count, $error_count > 1 ? "s" : "" );
+            }
         }
     }
     catch {
@@ -66,13 +73,16 @@ sub create_tidyall {
     my ( $self, $commit ) = @_;
 
     my $temp_dir = tempdir_simple();
-    foreach my $rel_file ( $self->conf_file, @{ $self->extra_conf_files } ) {
+    my @conf_names = $self->conf_name ? ( $self->conf_name ) : Code::TidyAll->default_conf_names;
+    my ($conf_file) = grep { $self->get_file_contents( $_, $commit ) } @conf_names
+      or die sprintf( "could not find conf file %s", join( " or ", @conf_names ) );
+    foreach my $rel_file ( $conf_file, @{ $self->extra_conf_files } ) {
         my $contents = $self->get_file_contents( $rel_file, $commit )
           or die sprintf( "could not find file '%s' in repo root", $rel_file );
         write_file( "$temp_dir/$rel_file", $contents );
     }
     my $tidyall = $self->tidyall_class->new_from_conf_file(
-        "$temp_dir/" . $self->conf_file,
+        "$temp_dir/" . $conf_file,
         mode  => 'commit',
         quiet => 1,
         %{ $self->tidyall_options },
@@ -92,10 +102,37 @@ sub get_changed_files {
 
 sub get_file_contents {
     my ( $self, $file, $commit ) = @_;
-    my $contents = capturex( $self->git_path, "show", "$commit:$file" );
+    my ( $contents, $error ) = capture { system( $self->git_path, "show", "$commit:$file" ) };
     return $contents;
 }
 
+sub check_repeated_push {
+    my ( $self, $input ) = @_;
+    if ( defined( my $allow = $self->allow_repeated_push ) ) {
+        my $cwd            = dirname( realpath($0) );
+        my $last_push_file = "$cwd/.prereceive_lastpush";
+        if ( -w $cwd || -w $last_push_file ) {
+            my $push_sig = sha1_hex($input);
+            if ( -f $last_push_file ) {
+                my ( $last_push_sig, $count ) = split( /\s+/, read_file($last_push_file) );
+                if ( $last_push_sig eq $push_sig ) {
+                    ++$count;
+                    print STDERR "*** Identical push seen $count times\n";
+                    if ( $count >= $allow ) {
+                        print STDERR "*** Allowing push to proceed despite errors\n";
+                        return 1;
+                    }
+                }
+                write_file( $last_push_file, join( " ", $push_sig, $count ) );
+            }
+            else {
+                write_file( $last_push_file, join( " ", $push_sig, 1 ) );
+            }
+        }
+    }
+    return 0;
+}
+
 1;
 
 
@@ -109,7 +146,7 @@ tidyall'd
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -155,11 +192,27 @@ is rejected and the reason(s) are output to the client. e.g.
     To ...
      ! [remote rejected] master -> master (pre-receive hook declined)
 
-The configuration file C<tidyall.ini> must be checked into git in the repo root
-directory, i.e. next to the .git directory.
+The configuration file (C<tidyall.ini> or C<.tidyallrc>) must be checked into
+git in the repo root directory, i.e. next to the .git directory.
 
-Unfortunately there is no easy way to bypass the pre-receive hook in an
-emergency.  It must be disabled in the repo being pushed to, e.g. by renaming
+In an emergency the hook can be bypassed by pushing the exact same set of
+commits 3 consecutive times (configurable via L</allow_repeated_push>):
+
+    % git push
+    ...
+    remote: 1 file did not pass tidyall check        
+
+    % git push
+    ...
+    *** Identical push seen 2 times
+    remote: 1 file did not pass tidyall check        
+
+    % git push
+    ...
+    *** Identical push seen 3 times
+    *** Allowing push to proceed despite errors
+
+Or you can disable the hook in the repo being pushed to, e.g. by renaming
 .git/hooks/pre-receive.
 
 Passes mode = "commit" by default; see L<modes|tidyall/MODES>.
@@ -168,19 +221,26 @@ Key/value parameters:
 
 =over
 
-=item conf_file
+=item allow_repeated_push
 
-Name of conf file; default is "tidyall.ini".
+Number of times a push must be repeated exactly after which it will be let
+through regardless of errors. Defaults to 3. Set to 0 or undef to disable this
+feature.
+
+=item conf_name
+
+Conf file name to search for instead of the defaults.
 
 =item extra_conf_files
 
-A listref of configuration files referred to from C<tidyall.ini>, e.g.
+A listref of extra configuration files referred to from the main configuration
+file, e.g.
 
     extra_conf_files => ['perlcriticrc', 'perltidyrc']
 
-These files will be pulled out of the repo along with tidyall.ini. If you don't
-list them here then you'll get errors like 'cannot find perlcriticrc' when the
-hook runs.
+These files will be pulled out of the repo alongside the main configuration
+file. If you don't list them here then you'll get errors like 'cannot find
+perlcriticrc' when the hook runs.
 
 =item git_path
 
