@@ -1,6 +1,6 @@
 package Code::TidyAll::Plugin::JSLint;
 BEGIN {
-  $Code::TidyAll::Plugin::JSLint::VERSION = '0.11';
+  $Code::TidyAll::Plugin::JSLint::VERSION = '0.12';
 }
 use Capture::Tiny qw(capture_merged);
 use Moo;
@@ -28,11 +28,11 @@ Code::TidyAll::Plugin::JSLint - use jslint with tidyall
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
-   In tidyall.ini:
+   In configuration:
 
    [JSLint]
    select = static/**/*.js
@@ -40,7 +40,7 @@ version 0.11
 
 =head1 DESCRIPTION
 
-Runs L<jslint|http://www.jslint.com/>, a Javascript validator, and dies if any
+Runs L<jslint|http://www.jslint.com/>, a JavaScript validator, and dies if any
 problems were found.
 
 =head1 INSTALLATION
