@@ -1,12 +1,11 @@
 package Code::TidyAll::Util;
 BEGIN {
-  $Code::TidyAll::Util::VERSION = '0.11';
+  $Code::TidyAll::Util::VERSION = '0.12';
 }
 use Cwd qw(realpath);
 use Data::Dumper;
 use File::Basename;
 use File::Path;
-use File::Slurp qw(read_file write_file);
 use File::Spec::Functions qw(abs2rel rel2abs);
 use File::Temp qw(tempdir);
 use Guard;
@@ -45,7 +44,7 @@ sub can_load {
 
 sub tempdir_simple {
     my $template = shift || 'Code-TidyAll-XXXX';
-    return realpath( tempdir( $template, TMPDIR => 1, CLEANUP => 0 ) );
+    return realpath( tempdir( $template, TMPDIR => 1, CLEANUP => 1 ) );
 }
 
 sub dump_one_line {
@@ -68,4 +67,17 @@ sub trim {
     return $str;
 }
 
+sub read_file {
+    my ($file) = @_;
+    open( my $fh, "<", $file ) or die "could not open $file: $!";
+    my $contents = do { local $/; <$fh> };
+    return $contents;
+}
+
+sub write_file {
+    my ( $file, $contents ) = @_;
+    open( my $fh, ">", $file ) or die "could not open $file: $!";
+    print $fh $contents;
+}
+
 1;
