@@ -1,6 +1,6 @@
 package Code::TidyAll::t::Basic;
 BEGIN {
-  $Code::TidyAll::t::Basic::VERSION = '0.11';
+  $Code::TidyAll::t::Basic::VERSION = '0.12';
 }
 use Cwd qw(realpath);
 use Code::TidyAll::Util qw(dirname mkpath pushd read_file tempdir_simple write_file);
@@ -139,6 +139,19 @@ sub test_quiet_and_verbose : Tests {
     }
 }
 
+sub test_iterations : Tests {
+    my $self     = shift;
+    my $root_dir = $self->create_dir( { "foo.txt" => "abc" } );
+    my $ct       = Code::TidyAll->new(
+        plugins    => { test_plugin('RepeatFoo') => { select => '**/foo*', times => 3 } },
+        root_dir   => $root_dir,
+        iterations => 2
+    );
+    my $file = "$root_dir/foo.txt";
+    $ct->process_files($file);
+    is( read_file($file), scalar( "abc" x 9 ), "3^2 = 9" );
+}
+
 sub test_caching_and_backups : Tests {
     my $self = shift;
 
@@ -242,7 +255,7 @@ sub test_errors : Tests {
             worse_param => 2
         );
     }
-    qr/unknown constructor param\(s\) 'bad_param', 'worse_param'/;
+    qr/unknown constructor params 'bad_param', 'worse_param'/;
 
     throws_ok {
         Code::TidyAll->new(
@@ -252,6 +265,16 @@ sub test_errors : Tests {
     }
     qr/could not load plugin class/;
 
+    throws_ok {
+        Code::TidyAll->new(
+            root_dir => $root_dir,
+            plugins  => {
+                test_plugin('UpperText') => { select => '**/*', bad_option => 1, worse_option => 2 }
+            }
+        )->plugin_objects;
+    }
+    qr/unknown options/;
+
     my $ct = Code::TidyAll->new( plugins => {%UpperText}, root_dir => $root_dir );
     my $output = capture_stdout { $ct->process_files("$root_dir/foo/bar.txt") };
     is( $output, "[tidied]  foo/bar.txt\n", "filename output" );
@@ -262,42 +285,45 @@ sub test_errors : Tests {
 }
 
 sub test_cli : Tests {
-    my $self      = shift;
-    my $root_dir  = $self->create_dir();
-    my $conf_file = "$root_dir/tidyall.ini";
-    write_file( $conf_file, $cli_conf );
+    my $self = shift;
 
-    write_file( "$root_dir/foo.txt", "hello" );
-    my $output = capture_stdout {
-        system( "$^X", "bin/tidyall", "$root_dir/foo.txt", "-v" );
-    };
+    foreach my $conf_name ( "tidyall.ini", ".tidyallrc" ) {
+        my $root_dir  = $self->create_dir();
+        my $conf_file = "$root_dir/$conf_name";
+        write_file( $conf_file, $cli_conf );
 
-    my ($params_msg) = ( $output =~ /constructing Code::TidyAll with these params:(.*)/ );
-    ok( defined($params_msg), "params msg" );
-    like( $params_msg, qr/backup_ttl => '15m'/,                              'backup_ttl' );
-    like( $params_msg, qr/verbose => '?1'?/,                                 'verbose' );
-    like( $params_msg, qr/\Qroot_dir => '$root_dir'\E/,                      'root_dir' );
-    like( $output,     qr/\[tidied\]  foo.txt \(.*RepeatFoo, .*UpperText\)/, 'foo.txt' );
-    is( read_file("$root_dir/foo.txt"), "HELLOHELLOHELLO", "tidied" );
+        write_file( "$root_dir/foo.txt", "hello" );
+        my $output = capture_stdout {
+            system( "$^X", "bin/tidyall", "$root_dir/foo.txt", "-v" );
+        };
 
-    mkpath( "$root_dir/subdir", 0, 0775 );
-    write_file( "$root_dir/subdir/foo.txt",  "bye" );
-    write_file( "$root_dir/subdir/foo2.txt", "bye" );
-    my $cwd = realpath();
-    capture_stdout {
-        system("cd $root_dir/subdir; $^X $cwd/bin/tidyall foo.txt");
-    };
-    is( read_file("$root_dir/subdir/foo.txt"),  "BYEBYEBYE", "foo.txt tidied" );
-    is( read_file("$root_dir/subdir/foo2.txt"), "bye",       "foo2.txt not tidied" );
+        my ($params_msg) = ( $output =~ /constructing Code::TidyAll with these params:(.*)/ );
+        ok( defined($params_msg), "params msg" );
+        like( $params_msg, qr/backup_ttl => '15m'/,                              'backup_ttl' );
+        like( $params_msg, qr/verbose => '?1'?/,                                 'verbose' );
+        like( $params_msg, qr/\Qroot_dir => '$root_dir'\E/,                      'root_dir' );
+        like( $output,     qr/\[tidied\]  foo.txt \(.*RepeatFoo, .*UpperText\)/, 'foo.txt' );
+        is( read_file("$root_dir/foo.txt"), "HELLOHELLOHELLO", "tidied" );
 
-    # Test -p / --pipe
-    #
-    my ( $stdout, $stderr ) = capture {
-        open( my $fh, "|-", "$^X", "bin/tidyall", "-p", "$root_dir/does_not_exist/foo.txt" );
-        print $fh "echo";
-    };
-    is( $stdout, "ECHOECHOECHO", "pipe: stdin tidied" );
-    unlike( $stderr, qr/\S/, "pipe: no stderr" );
+        mkpath( "$root_dir/subdir", 0, 0775 );
+        write_file( "$root_dir/subdir/foo.txt",  "bye" );
+        write_file( "$root_dir/subdir/foo2.txt", "bye" );
+        my $cwd = realpath();
+        capture_stdout {
+            system("cd $root_dir/subdir; $^X $cwd/bin/tidyall foo.txt");
+        };
+        is( read_file("$root_dir/subdir/foo.txt"),  "BYEBYEBYE", "foo.txt tidied" );
+        is( read_file("$root_dir/subdir/foo2.txt"), "bye",       "foo2.txt not tidied" );
+
+        # Test -p / --pipe
+        #
+        my ( $stdout, $stderr ) = capture {
+            open( my $fh, "|-", "$^X", "bin/tidyall", "-p", "$root_dir/does_not_exist/foo.txt" );
+            print $fh "echo";
+        };
+        is( $stdout, "ECHOECHOECHO", "pipe: stdin tidied" );
+        unlike( $stderr, qr/\S/, "pipe: no stderr" );
+    }
 }
 
 $cli_conf = '
